@@ -7,13 +7,11 @@ has_internet <- function() {
 test_that("ucsc connection works", {
   skip("run db tests manually.")
   skip_if_not_installed("curl")
-  skip_if_not_installed("RMySQL")
+  skip_if_not_installed("RMariaDB")
 
   if (!has_internet()) skip("no internet connection")
 
   skip_on_cran()
-  skip_on_travis()
-  skip_on_appveyor()
 
   db <- db_ucsc("hg38")
   refgene <- tbl(db, "refGene")
@@ -24,13 +22,11 @@ test_that("ucsc connection works", {
 test_that("ensembl connection works", {
   skip("run db tests manually.")
   skip_if_not_installed("curl")
-  skip_if_not_installed("RMySQL")
+  skip_if_not_installed("RMariaDB")
 
   if (!has_internet()) skip("no internet connection")
 
   skip_on_cran()
-  skip_on_travis()
-  skip_on_appveyor()
 
   db <- db_ensembl("spermophilus_tridecemlineatus_core_67_2")
   gene <- tbl(db, "gene")
